pub struct BufferOutput { /* private fields */ }Expand description
An Output implementation that writes lines to an internal buffer.
Implementations
Sourceimpl BufferOutput
impl BufferOutput
Sourcepub fn take_lines(&self) -> Result<Vec<String>, OTelSdkError>
pub fn take_lines(&self) -> Result<Vec<String>, OTelSdkError>
Retrieves all lines currently in the buffer, clearing the buffer afterwards.